aboutsummaryrefslogtreecommitdiffstats
path: root/modules
diff options
context:
space:
mode:
authorMilan Crha <mcrha@redhat.com>2010-04-01 22:18:40 +0800
committerMilan Crha <mcrha@redhat.com>2010-04-01 22:18:40 +0800
commitb276c75c7c0f537cf4f5d122b1bff41420ca3232 (patch)
tree829da2bb5e4c2795c884d0e53ffd0da1b344dfb1 /modules
parentba1c4eade6a41d285fae59969f2db4b253139041 (diff)
downloadgsoc2013-evolution-b276c75c7c0f537cf4f5d122b1bff41420ca3232.tar
gsoc2013-evolution-b276c75c7c0f537cf4f5d122b1bff41420ca3232.tar.gz
gsoc2013-evolution-b276c75c7c0f537cf4f5d122b1bff41420ca3232.tar.bz2
gsoc2013-evolution-b276c75c7c0f537cf4f5d122b1bff41420ca3232.tar.lz
gsoc2013-evolution-b276c75c7c0f537cf4f5d122b1bff41420ca3232.tar.xz
gsoc2013-evolution-b276c75c7c0f537cf4f5d122b1bff41420ca3232.tar.zst
gsoc2013-evolution-b276c75c7c0f537cf4f5d122b1bff41420ca3232.zip
Bug #613352 - Changed time range not propagated to calendar
Diffstat (limited to 'modules')
-rw-r--r--modules/calendar/e-cal-shell-view-private.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/modules/calendar/e-cal-shell-view-private.c b/modules/calendar/e-cal-shell-view-private.c
index 8806ad691b..dc30897aab 100644
--- a/modules/calendar/e-cal-shell-view-private.c
+++ b/modules/calendar/e-cal-shell-view-private.c
@@ -219,7 +219,7 @@ cal_shell_view_date_navigator_scroll_event_cb (ECalShellView *cal_shell_view,
* we could move this handler into ECalShellSidebar. */
e_calendar_item_set_selection (calitem, &start_date, &end_date);
- cal_shell_view_date_navigator_date_range_changed_cb (
+ cal_shell_view_date_navigator_selection_changed_cb (
cal_shell_view, calitem);
}
@@ -459,8 +459,10 @@ e_cal_shell_view_private_constructed (ECalShellView *cal_shell_view)
selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
date_navigator = e_cal_shell_sidebar_get_date_navigator (cal_shell_sidebar);
/* Give GnomeCalendar a handle to the date navigator. */
gnome_calendar_set_date_navigator (calendar, date_navigator);
+ gnome_calendar_set_memo_table (calendar, memo_table ? GTK_WIDGET (memo_table) : NULL);
+ gnome_calendar_set_task_table (calendar, task_table ? GTK_WIDGET (task_table) : NULL);
e_calendar_item_set_get_time_callback (
date_navigator->calitem, (ECalendarItemGetTimeCallback)
@@ -459,8 +459,10 @@ e_cal_shell_view_private_constructed (ECalShellView *cal_shell_view)
selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
date_navigator = e_cal_shell_sidebar_get_date_navigator (cal_shell_sidebar);
- /* Give GnomeCalendar a handle to the date navigator. */
+ /* Give GnomeCalendar a handle to the date navigator, memo and task table. */
gnome_calendar_set_date_navigator (calendar, date_navigator);